==> openshift-model-monitoring-5.7.3-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ThanosSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ThanosSpecFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getBaseImage();
  public A withBaseImage(java.lang.String baseImage);
  public java.lang.Boolean hasBaseImage();
  
  /**
   * Method is deprecated. use withBaseImage instead.
   */
  @java.lang.Deprecated
  public A withNewBaseImage(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildGrpcServerTlsConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig getGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig buildGrpcServerTlsConfig();
  public A withGrpcServerTlsConfig(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig grpcServerTlsConfig);
  public java.lang.Boolean hasGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> withNewGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> withNewGrpcServerTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> editGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> editOrNewGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> editOrNewGrpcServerTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public java.lang.String getImage();
  public A withImage(java.lang.String image);
  public java.lang.Boolean hasImage();
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0);
  public java.lang.Boolean getListenLocal();
  public A withListenLocal(java.lang.Boolean listenLocal);
  public java.lang.Boolean hasListenLocal();
  public java.lang.String getLogFormat();
  public A withLogFormat(java.lang.String logFormat);
  public java.lang.Boolean hasLogFormat();
  
  /**
   * Method is deprecated. use withLogFormat instead.
   */
  @java.lang.Deprecated
  public A withNewLogFormat(java.lang.String arg0);
  public java.lang.String getLogLevel();
  public A withLogLevel(java.lang.String logLevel);
  public java.lang.Boolean hasLogLevel();
  
  /**
   * Method is deprecated. use withLogLevel instead.
   */
  @java.lang.Deprecated
  public A withNewLogLevel(java.lang.String arg0);
  public java.lang.String getMinTime();
  public A withMinTime(java.lang.String minTime);
  public java.lang.Boolean hasMinTime();
  
  /**
   * Method is deprecated. use withMinTime instead.
   */
  @java.lang.Deprecated
  public A withNewMinTime(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.SecretKeySelector getObjectStorageConfig();
  public A withObjectStorageConfig(io.fabric8.kubernetes.api.model.SecretKeySelector objectStorageConfig);
  public java.lang.Boolean hasObjectStorageConfig();
  public A withNewObjectStorageConfig(java.lang.String key,java.lang.String name,java.lang.Boolean optional);
  public java.lang.String getObjectStorageConfigFile();
  public A withObjectStorageConfigFile(java.lang.String objectStorageConfigFile);
  public java.lang.Boolean hasObjectStorageConfigFile();
  
  /**
   * Method is deprecated. use withObjectStorageConfigFile instead.
   */
  @java.lang.Deprecated
  public A withNewObjectStorageConfigFile(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceRequirements getResources();
  public io.fabric8.kubernetes.api.model.ResourceRequirements buildResources();
  public A withResources(io.fabric8.kubernetes.api.model.ResourceRequirements resources);
  public java.lang.Boolean hasResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> withNewResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> withNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> editResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> editOrNewResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> editOrNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  public java.lang.String getSha();
  public A withSha(java.lang.String sha);
  public java.lang.Boolean hasSha();
  
  /**
   * Method is deprecated. use withSha instead.
   */
  @java.lang.Deprecated
  public A withNewSha(java.lang.String arg0);
  public java.lang.String getTag();
  public A withTag(java.lang.String tag);
  public java.lang.Boolean hasTag();
  
  /**
   * Method is deprecated. use withTag instead.
   */
  @java.lang.Deprecated
  public A withNewTag(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.SecretKeySelector getTracingConfig();
  public A withTracingConfig(io.fabric8.kubernetes.api.model.SecretKeySelector tracingConfig);
  public java.lang.Boolean hasTracingConfig();
  public A withNewTracingConfig(java.lang.String key,java.lang.String name,java.lang.Boolean optional);
  public java.lang.String getTracingConfigFile();
  public A withTracingConfigFile(java.lang.String tracingConfigFile);
  public java.lang.Boolean hasTracingConfigFile();
  
  /**
   * Method is deprecated. use withTracingConfigFile instead.
   */
  @java.lang.Deprecated
  public A withNewTracingConfigFile(java.lang.String arg0);
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public interface GrpcServerTlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.TLSConfigFluent<io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<N>>{
    public N and();
    public N endGrpcServerTlsConfig();
    
  }
  public interface ResourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  
}

==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ThanosSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ThanosSpecFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getBaseImage();
  public A withBaseImage(java.lang.String baseImage);
  public java.lang.Boolean hasBaseImage();
  
  /**
   * Method is deprecated. use withBaseImage instead.
   */
  @java.lang.Deprecated
  public A withNewBaseImage(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildGrpcServerTlsConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig getGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig buildGrpcServerTlsConfig();
  public A withGrpcServerTlsConfig(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig grpcServerTlsConfig);
  public java.lang.Boolean hasGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> withNewGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> withNewGrpcServerTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> editGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> editOrNewGrpcServerTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<A> editOrNewGrpcServerTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public java.lang.String getImage();
  public A withImage(java.lang.String image);
  public java.lang.Boolean hasImage();
  
  /**
   * Method is deprecated. use withImage instead.
   */
  @java.lang.Deprecated
  public A withNewImage(java.lang.String arg0);
  public java.lang.Boolean getListenLocal();
  public A withListenLocal(java.lang.Boolean listenLocal);
  public java.lang.Boolean hasListenLocal();
  public java.lang.String getLogFormat();
  public A withLogFormat(java.lang.String logFormat);
  public java.lang.Boolean hasLogFormat();
  
  /**
   * Method is deprecated. use withLogFormat instead.
   */
  @java.lang.Deprecated
  public A withNewLogFormat(java.lang.String arg0);
  public java.lang.String getLogLevel();
  public A withLogLevel(java.lang.String logLevel);
  public java.lang.Boolean hasLogLevel();
  
  /**
   * Method is deprecated. use withLogLevel instead.
   */
  @java.lang.Deprecated
  public A withNewLogLevel(java.lang.String arg0);
  public java.lang.String getMinTime();
  public A withMinTime(java.lang.String minTime);
  public java.lang.Boolean hasMinTime();
  
  /**
   * Method is deprecated. use withMinTime instead.
   */
  @java.lang.Deprecated
  public A withNewMinTime(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.SecretKeySelector getObjectStorageConfig();
  public A withObjectStorageConfig(io.fabric8.kubernetes.api.model.SecretKeySelector objectStorageConfig);
  public java.lang.Boolean hasObjectStorageConfig();
  public A withNewObjectStorageConfig(java.lang.String key,java.lang.String name,java.lang.Boolean optional);
  public java.lang.String getObjectStorageConfigFile();
  public A withObjectStorageConfigFile(java.lang.String objectStorageConfigFile);
  public java.lang.Boolean hasObjectStorageConfigFile();
  
  /**
   * Method is deprecated. use withObjectStorageConfigFile instead.
   */
  @java.lang.Deprecated
  public A withNewObjectStorageConfigFile(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ResourceRequirements getResources();
  public io.fabric8.kubernetes.api.model.ResourceRequirements buildResources();
  public A withResources(io.fabric8.kubernetes.api.model.ResourceRequirements resources);
  public java.lang.Boolean hasResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> withNewResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> withNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> editResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> editOrNewResources();
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<A> editOrNewResourcesLike(io.fabric8.kubernetes.api.model.ResourceRequirements item);
  public java.lang.String getSha();
  public A withSha(java.lang.String sha);
  public java.lang.Boolean hasSha();
  
  /**
   * Method is deprecated. use withSha instead.
   */
  @java.lang.Deprecated
  public A withNewSha(java.lang.String arg0);
  public java.lang.String getTag();
  public A withTag(java.lang.String tag);
  public java.lang.Boolean hasTag();
  
  /**
   * Method is deprecated. use withTag instead.
   */
  @java.lang.Deprecated
  public A withNewTag(java.lang.String arg0);
  public io.fabric8.kubernetes.api.model.SecretKeySelector getTracingConfig();
  public A withTracingConfig(io.fabric8.kubernetes.api.model.SecretKeySelector tracingConfig);
  public java.lang.Boolean hasTracingConfig();
  public A withNewTracingConfig(java.lang.String key,java.lang.String name,java.lang.Boolean optional);
  public java.lang.String getTracingConfigFile();
  public A withTracingConfigFile(java.lang.String tracingConfigFile);
  public java.lang.Boolean hasTracingConfigFile();
  
  /**
   * Method is deprecated. use withTracingConfigFile instead.
   */
  @java.lang.Deprecated
  public A withNewTracingConfigFile(java.lang.String arg0);
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface GrpcServerTlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.TLSConfigFluent<io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.GrpcServerTlsConfigNested<N>>{
    public N and();
    public N endGrpcServerTlsConfig();
    
  }
  public interface ResourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ResourceRequirementsFluent<io.fabric8.openshift.api.model.monitoring.v1.ThanosSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  
}
